@@ -4,18 +4,25 @@ use crate::{
 };
 use eyre::{Context, Result};
 use rustsec::{Report, Vulnerability};
-use std::process::{Command, Stdio};
-use tracing::{debug, error, info, trace};
+use std::{fs::File, path::PathBuf};
+use tracing::{error, info};
 
 const AUDIT_ENGINE: &str = "audit";
 
 pub struct Audit<'ranges> {
+    json: PathBuf,
     cargo_ranges: &'ranges CargoRanges,
 }
 
 impl<'ranges> Audit<'ranges> {
-    pub fn new(cargo_ranges: &'ranges CargoRanges) -> Self {
-        Self { cargo_ranges }
+    pub fn new<P>(json: P, cargo_ranges: &'ranges CargoRanges) -> Self
+    where
+        P: Into<PathBuf>,
+    {
+        Self {
+            json: json.into(),
+            cargo_ranges,
+        }
     }
 
     // FIXME: reporting on 'Cargo.toml' is a bad idea because the vulnerability might exist on a nested dependency
@@ -78,24 +85,10 @@ impl std::convert::TryInto<Issues> for Audit<'_> {
     type Error = eyre::Error;
 
     fn try_into(self) -> Result<Issues> {
-        trace!("prepare `cargo clippy` command");
-        // FIXME: replace with 'cargo-deny' which provides more functionalities and a graph of dependencies
-        let mut cmd = Command::new("cargo");
-        cmd.arg("audit")
-            .arg("--json")
-            .stdout(Stdio::piped())
-            .stderr(Stdio::null());
-        debug!("execute `{:?}`", cmd);
-        let child_stdout = cmd.spawn()?.stdout;
-        let issues = if let Some(mut stdout) = child_stdout {
-            let mut output = String::new();
-            std::io::Read::read_to_string(&mut stdout, &mut output)?;
-            let report = serde_json::from_str::<Report>(&output)
-                .context("failed to be parsed as a 'rustsec::report::Report'")?;
-            self.to_issues(report)
-        } else {
-            Issues::default()
-        };
+        let file = File::open(&self.json)?;
+        let report = serde_json::from_reader::<_, Report>(file)
+            .context("failed to be parsed as a 'rustsec::report::Report'")?;
+        let issues = self.to_issues(report);
         info!("{} sonar issues created", issues.len());
         Ok(issues)
     }
