@@ -32,8 +32,8 @@ fn main() -> Result<()> {
     color_eyre::install()?;
     let cargo_ranges =
         CargoRanges::try_from(std::env::current_dir()?.join("Cargo.toml").as_path())?;
-    let clippy_issues: Issues = Clippy::new().try_into()?;
-    let audit_issues: Issues = Audit::new(&cargo_ranges).try_into()?;
+    let clippy_issues: Issues = Clippy::new("clippy.json").try_into()?;
+    let audit_issues: Issues = Audit::new("audit.json", &cargo_ranges).try_into()?;
 
     let mut issues = clippy_issues;
     issues.extend(audit_issues);
